@@ -2,18 +2,18 @@
 RESTful resource variant selection using the HTTP Accept header.
 """
 
-__version__   = '0.3'
+__version__   = '0.3.1'
 __author__    = 'Martin Blech <martinblech@gmail.com>'
 __license__   = 'MIT'
 
 import mimeparse
-
-# ctx = web.threadeddict()
+from functools import wraps
 
 class MimeRenderException(Exception): pass
 
 XML   = 'xml'
 JSON  = 'json'
+BSON  = 'bson'
 YAML  = 'yaml'
 XHTML = 'xhtml'
 HTML  = 'html'
@@ -33,6 +33,7 @@ KMZ   = 'kmz'
 _MIME_TYPES = {
     XML:   ('application/xml', 'text/xml', 'application/x-xml',),
     JSON:  ('application/json',),
+    BSON:  ('application/bson',),
     YAML:  ('application/x-yaml', 'text/yaml',),
     XHTML: ('application/xhtml+xml',),
     HTML:  ('text/html',),
@@ -142,12 +143,19 @@ class MimeRenderBase(object):
                 supported.append(mime)
                 renderer_dict[mime] = renderer
         if default:
-            default_mime = _get_mime_types(default)[0]
+            default_mimes = _get_mime_types(default)
+            # default mime types should be last in the supported list
+            # (which means highest priority to mimeparse)
+            for mime in reversed(default_mimes):
+                supported.remove(mime)
+                supported.append(mime)
+            default_mime = default_mimes[0]
             default_renderer = get_renderer(default_mime)
         else:
             default_mime, default_renderer = renderer_dict.items()[0]
         
         def wrap(target):
+            @wraps(target)
             def wrapper(*args, **kwargs):
                 mime = None
                 shortmime = None
@@ -343,5 +351,26 @@ if __name__ == "__main__":
             result = handler('c')
             self.assertEquals(mimerender.content_type, 'text/html')
             self.assertEquals(result, 'html:c')
+
+        def test_default_for_wildcard_query(self):
+            mimerender = TestMimeRender()
+            mimerender.accept_header = '*/*'
+            mimerender(
+                    default='xml',
+                    txt=lambda: None,
+                    xml=lambda: None)(lambda: {})()
+            self.assertEquals(mimerender.content_type, _MIME_TYPES['xml'][0])
+            mimerender(
+                    default='txt',
+                    txt=lambda: None,
+                    xml=lambda: None)(lambda: {})()
+            self.assertEquals(mimerender.content_type, _MIME_TYPES['txt'][0])
+
+        def test_decorated_function_name(self):
+            def vanilla_function(): pass
+            mimerender = TestMimeRender()
+            decorated_function = mimerender(xml=None)(vanilla_function)
+            self.assertEquals(vanilla_function.__name__,
+                    decorated_function.__name__)
     
     unittest.main()
